import { Construct } from 'constructs';
import { TerraformInjectorClass, TerraformInjector, TerraformInjectorAsync } from '../../../module';
export declare const injectorMap: Map<Construct, TerraformInjectorClass>;
/**
 * Constant object for creating {@link TerraformInjector} or {@link TerraformInjectorAsync} instance.
 * You can use only one of ```scopesOn``` or ```scopesOnAsync``` function for one {@link https://www.npmjs.com/package/constructs Construct} instance, not both.
 *
 * @see https://www.terraform.io/cdktf/concepts/constructs
 */
export declare const TerraformInjectorFactory: {
    /**
     * Create or get a {@link TerraformInjector} instance on a certain {@link https://www.npmjs.com/package/constructs Construct} scope.
     *
     * @param {Construct} scope {@link https://www.npmjs.com/package/constructs Construct} instance that {@link TerraformInjector} scopes on.
     *
     * @param {string} description Optional description string for the injector instance.
     *
     * @returns {TerraformInjector}
     *
     * @throws ```Conflicted Injecting Method Type``` : When you already have used ```scopesOnAsync``` function for the same scope.
     */
    scopesOn: (scope: Construct, description?: string | undefined) => TerraformInjector;
    /**
     * Create or get a {@link TerraformInjectorAsync} instance on a certain {@link https://www.npmjs.com/package/constructs Construct} scope.
     *
     * @param {Construct} scope {@link https://www.npmjs.com/package/constructs Construct} instance that {@link TerraformInjectorAsync} scopes on.
     *
     * @param {string} description Optional description string for the injector instance.
     *
     * @returns {TerraformInjectorAsync}
     *
     * @throws ```Conflicted Injecting Method Type``` : When you already have used ```scopesOn``` function for the same scope.
     */
    scopesOnAsync: (scope: Construct, description?: string | undefined) => TerraformInjectorAsync;
};
